@@ -5,7 +5,6 @@ import datetime
 import decimal
 import fractions
 import re
-import sys
 import uuid
 
 import pyrfc3339
@@ -16,16 +15,7 @@ from .char import Char
 from .edn_lex import Keyword, Symbol
 from .edn_parse import TaggedElement
 
-
-# alias Python 2 types to their corresponding types in Python 3 if necessary
-if sys.version_info[0] >= 3:
-    __PY3 = True
-    long = int
-    basestring = str
-    unicode = str
-    unichr = chr
-else:
-    __PY3 = False
+from .compat import _PY3, long, basestring, unicode, unichr
 
 
 DEFAULT_INPUT_ENCODING = 'utf-8'
@@ -72,7 +62,8 @@ def dump_char(c):
         return SPECIAL_CHARS[c]
 
     # [2:] to strip the '0x' prefix
-    return "\\u{}".format(hex(ord(c))[2:].upper().rjust(4, "0"))
+    # str("0") because it must be an str and not a unicode in Python 2.
+    return "\\u{}".format(hex(ord(c))[2:].upper().rjust(4, str("0")))
 
 
 def indent_lines(lines, open_sym, close_sym, indent, indent_step):
@@ -215,6 +206,6 @@ def dump(obj,
                     sort_keys=sort_keys,
                     sort_sets=sort_sets,
                     indent=indent)
-    if __PY3:
+    if _PY3:
         return outcome
     return outcome.encode(output_encoding)
