@@ -8,7 +8,6 @@ import decimal
 import fractions
 import logging
 import re
-import sys
 
 
 import ply.lex
@@ -17,14 +16,7 @@ from .exceptions import EDNDecodeError
 from .immutable_dict import ImmutableDict
 from .char import Char
 
-
-if sys.version_info[0] == 3:
-    long = int
-    basestring = str
-    unicode = str
-    def _bytes(s): return bytes(s, 'utf-8')
-else:
-    _bytes = bytes
+from .compat import unicode, _bytes
 
 
 ESCAPE_SEQUENCE_RE = re.compile(r'''
@@ -217,7 +209,9 @@ def t_CHAR(t):
     # uXXXX hex code or from "!" to "~" = all printable ASCII chars except the space
     # or unicode word chars
     r"(\\u[0-9A-Fa-f]{4}|\\[!-~\w])"
-    t.value = Char(t.value[1] if len(t.value) == 2 else _bytes(t.value).decode('raw_unicode_escape'))
+    t.value = Char(t.value[1]
+                   if len(t.value) == 2
+                   else _bytes(t.value).decode('raw_unicode_escape'))
     return t
 
 
