@@ -16,6 +16,8 @@ from edn_format import edn_lex, edn_parse, \
     TaggedElement, add_tag, remove_tag, tag, \
     EDNDecodeError
 
+from edn_format.compat import _PY3, unicode
+
 
 class ConsoleTest(unittest.TestCase):
     def test_dumping(self):
@@ -67,7 +69,7 @@ class EdnTest(unittest.TestCase):
             "LexToken(SYMBOL,None,1,4), " +
             "LexToken(SYMBOL,False,1,8)]",
             "456 nil false")
-        self.check_lex("[LexToken(CHAR,'c',1,0)]",
+        self.check_lex("[LexToken(CHAR,'c',1,0)]" if _PY3 else "[LexToken(CHAR,u'c',1,0)]",
                        r"\c")
         self.check_lex("[LexToken(KEYWORD,Keyword(abc),1,0)]",
                        r":abc")
@@ -336,7 +338,7 @@ class EdnTest(unittest.TestCase):
     def check_char(self, expected, name):
         edn_data = "\\{}".format(name)
         parsed = loads(edn_data)
-        self.assertIsInstance(parsed, str)
+        self.assertIsInstance(parsed, unicode)
         self.assertEqual(expected, parsed, edn_data)
 
         self.assertIsInstance(parsed, Char)
